@@ -9,16 +9,15 @@ import (
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
-var DeleteCmd = base.DeleteCmd{
+var DeleteCmd = base.DeleteCmd[*hcloud.FloatingIP]{
 	ResourceNameSingular: "Floating IP",
 	ResourceNamePlural:   "Floating IPs",
 	ShortDescription:     "Delete a Floating IP",
 	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.FloatingIP().Names },
-	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
+	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (*hcloud.FloatingIP, *hcloud.Response, error) {
 		return s.Client().FloatingIP().Get(s, idOrName)
 	},
-	Delete: func(s state.State, _ *cobra.Command, resource interface{}) (*hcloud.Action, error) {
-		floatingIP := resource.(*hcloud.FloatingIP)
+	Delete: func(s state.State, _ *cobra.Command, floatingIP *hcloud.FloatingIP) (*hcloud.Action, error) {
 		_, err := s.Client().FloatingIP().Delete(s, floatingIP)
 		return nil, err
 	},
