@@ -9,16 +9,15 @@ import (
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
-var DeleteCmd = base.DeleteCmd{
+var DeleteCmd = base.DeleteCmd[*hcloud.PrimaryIP]{
 	ResourceNameSingular: "Primary IP",
 	ResourceNamePlural:   "Primary IPs",
 	ShortDescription:     "Delete a Primary IP",
-	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.PrimaryIP().Names },
-	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
+	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.PrimaryIP().Names(false, false, nil) },
+	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (*hcloud.PrimaryIP, *hcloud.Response, error) {
 		return s.Client().PrimaryIP().Get(s, idOrName)
 	},
-	Delete: func(s state.State, _ *cobra.Command, resource interface{}) (*hcloud.Action, error) {
-		primaryIP := resource.(*hcloud.PrimaryIP)
+	Delete: func(s state.State, _ *cobra.Command, primaryIP *hcloud.PrimaryIP) (*hcloud.Action, error) {
 		_, err := s.Client().PrimaryIP().Delete(s, primaryIP)
 		return nil, err
 	},
